@@ -9,7 +9,15 @@ from webspace.cms.blocks.common import \
     ButtonBlock, \
     EntryBlock, \
     EmbedWithSizeBlock, \
-    FormBlock
+    FormBlock, \
+    GalleryBlock
+
+
+class GallerySlider(GalleryBlock):
+
+    class Meta:
+        template = '%s/common/gallery_slider.html' % constants.BLOCK_TEMPLATES_PATH
+        label = "Gallery Slider"
 
 
 class ComponentTextEntry(EntryBlock):
@@ -26,6 +34,7 @@ class ComponentTextEntry(EntryBlock):
             ('image', ImageWithSizeBlock()),
             ('embed', EmbedWithSizeBlock()),
             ('form', FormBlock()),
+            ('gallery_slider', GallerySlider())
         ],
         max_num=1,
         required=False
