@@ -41,6 +41,33 @@ def register_mark_feature(features):
     features.default_features.append('mark')
 
 
+# Shadow
+
+@hooks.register('register_rich_text_features')
+def register_shadow_feature(features):
+    feature_name = 'shadow'
+    type_ = 'SHADOW'
+    tag = 'shadow'
+
+    control = {
+        'type': type_,
+        'label': '+',
+        'description': 'Shadow',
+    }
+
+    features.register_editor_plugin(
+        'draftail', feature_name, draftail_features.InlineStyleFeature(control)
+    )
+
+    db_conversion = {
+        'from_database_format': {tag: InlineStyleElementHandler(type_)},
+        'to_database_format': {'style_map': {type_: tag}},
+    }
+
+    features.register_converter_rule('contentstate', feature_name, db_conversion)
+    features.default_features.append('shadow')
+
+
 #  RichText Code Blocks
 
 class PreformattedTextElementHandler(BlockElementHandler):
